You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@spamassassin.apache.org by qu...@apache.org on 2004/07/16 10:33:20 UTC

svn commit: rev 22962 - in spamassassin/trunk/lib/Mail: . SpamAssassin SpamAssassin/Message

Author: quinlan
Date: Fri Jul 16 01:33:20 2004
New Revision: 22962

Modified:
   spamassassin/trunk/lib/Mail/SpamAssassin.pm
   spamassassin/trunk/lib/Mail/SpamAssassin/ArchiveIterator.pm
   spamassassin/trunk/lib/Mail/SpamAssassin/Constants.pm
   spamassassin/trunk/lib/Mail/SpamAssassin/Message.pm
   spamassassin/trunk/lib/Mail/SpamAssassin/Message/Node.pm
   spamassassin/trunk/lib/Mail/SpamAssassin/PerMsgStatus.pm
Log:
it's "separator"


Modified: spamassassin/trunk/lib/Mail/SpamAssassin.pm
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin.pm	(original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin.pm	Fri Jul 16 01:33:20 2004
@@ -837,7 +837,7 @@
   my ($self, $mail_obj) = @_;
   local ($_);
 
-  my $mbox = $mail_obj->get_mbox_seperator() || '';
+  my $mbox = $mail_obj->get_mbox_separator() || '';
 
   dbg("Removing Markup");
 

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/ArchiveIterator.pm
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin/ArchiveIterator.pm	(original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/ArchiveIterator.pm	Fri Jul 16 01:33:20 2004
@@ -599,7 +599,7 @@
 	# skip mbx headers to the first email...
 	seek(INPUT, 2048, 0) ;
 
-        my $sep = MBX_SEPERATOR;
+        my $sep = MBX_SEPARATOR;
     
 	while (<INPUT>) {
 	    if ($_ =~ /$sep/) {
@@ -699,7 +699,7 @@
     seek(INPUT, $offset, 0) ;
     
     while (<INPUT>) {
-	last if ($_ =~ MBX_SEPERATOR) ;
+	last if ($_ =~ MBX_SEPARATOR) ;
 	
 	# skip mails that are too big
 	if (! $self->{opt_all} && @msg > BIG_LINES) {

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/Constants.pm
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin/Constants.pm	(original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/Constants.pm	Fri Jul 16 01:33:20 2004
@@ -34,7 +34,7 @@
 );
 # These are generic constants that may be used across several modules
 @SA_VARS = qw(
-	META_TEST_MIN_PRIORITY HARVEST_DNSBL_PRIORITY MBX_SEPERATOR
+	META_TEST_MIN_PRIORITY HARVEST_DNSBL_PRIORITY MBX_SEPARATOR
 );
 
 %EXPORT_TAGS = (
@@ -168,9 +168,9 @@
 use constant META_TEST_MIN_PRIORITY => 500;
 use constant HARVEST_DNSBL_PRIORITY => 500;
 
-# Regular expression that matches message sperators in The University of
-# Washington's MBX mailbox format...
-use constant MBX_SEPERATOR => qr/([\s|\d]\d-[a-zA-Z]{3}-\d{4}\s\d{2}:\d{2}:\d{2}.*),(\d+);([\da-f]{12})-(\w{8})/ ;
+# regular expression that matches message separators in The University of
+# Washington's MBX mailbox format
+use constant MBX_SEPARATOR => qr/([\s|\d]\d-[a-zA-Z]{3}-\d{4}\s\d{2}:\d{2}:\d{2}.*),(\d+);([\da-f]{12})-(\w{8})/;
 # $1 = datestamp (str)
 # $2 = size of message in bytes (int)
 # $3 = message status - binary (hex)

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/Message.pm
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin/Message/Node.pm	(original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/Message/Node.pm	Fri Jul 16 01:33:20 2004
@@ -577,7 +577,7 @@
 Retrieve all headers.  Each header will have a newline at the end and
 will be unfolded.  The first parameter (optional) is whether or not to
 return the raw headers, and the second parameter (optional) is whether
-or not to include the mbox seperator.
+or not to include the mbox separator.
 
 If get_all_header() is called in an array context, an array will be
 returned with each header entry in a different element.  In a scalar

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/PerMsgStatus.pm
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin/PerMsgStatus.pm	(original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/PerMsgStatus.pm	Fri Jul 16 01:33:20 2004
@@ -625,7 +625,7 @@
 sub rewrite_mail {
   my ($self) = @_;
 
-  my $mbox = $self->{msg}->get_mbox_seperator() || '';
+  my $mbox = $self->{msg}->get_mbox_separator() || '';
   if ($self->{is_spam} && $self->{conf}->{report_safe}) {
     return $mbox.$self->rewrite_report_safe();
   }

Re: svn commit: rev 22962 - in spamassassin/trunk/lib/Mail: . SpamAssassin SpamAssassin/Message

Posted by Daniel Quinlan <qu...@pathname.com>.
Theo Van Dinter <fe...@kluge.net> writes:

> FYI: I reverted the change.  r22977.

I would have reverted the change if asked and I was anticipating a vote
rather than being reverted.  I don't think we need to revert changes on
procedural grounds.

--- spamassassin/trunk/lib/Mail/SpamAssassin/Message.pm	(original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/Message.pm	Fri Jul 16 01:33:20 2004
@@ -129,8 +129,8 @@
 	# mbox formated mailbox
 	$self->{'mbox_sep'} = $last;
 	next;
-    } elsif ($last =~ MBX_SEPERATOR) {
-	# Munge the mbx message seperator into mbox format as a sort of
+    } elsif ($last =~ MBX_SEPARATOR) {
+	# Munge the mbx message separator into mbox format as a sort of
 	# de facto portability standard in SA's internals.  We need to
 	# to this so that Mail::SpamAssassin::Util::parse_rfc822_date
 	# can parse the date string...
@@ -303,14 +303,14 @@
   }
 }
 
-=item get_mbox_seperator()
+=item get_mbox_separator()
 
-Returns the mbox seperator found in the message, or undef if there
+Returns the mbox separator found in the message, or undef if there
 wasn't one.
 
 =cut
 
-sub get_mbox_seperator {
+sub get_mbox_separator {
   return $_[0]->{mbox_sep};
 }
 

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/Message/Node.pm
==============================================================================
-- 
Daniel Quinlan
http://www.pathname.com/~quinlan/

Re: svn commit: rev 22962 - in spamassassin/trunk/lib/Mail: . SpamAssassin SpamAssassin/Message

Posted by Theo Van Dinter <fe...@kluge.net>.
On Fri, Jul 16, 2004 at 11:54:23AM -0700, Justin Mason wrote:
> (I also agree it's a reasonable change, but we need to vote on it.)

FYI: I reverted the change.  r22977.

-- 
Randomly Generated Tagline:
"Programming isn't so much a profession as it is an obsessive-compulsive
 disorder."                  - Unknown

Re: svn commit: rev 22962 - in spamassassin/trunk/lib/Mail: . SpamAssassin SpamAssassin/Message

Posted by Theo Van Dinter <fe...@kluge.net>.
On Fri, Jul 16, 2004 at 02:15:12PM -0500, Michael Parker wrote:
> +1 for the change, I agree that it needs a vote, but I don't agree
> that we need to spend a lot of time debating that it needs a vote and
> reverting the code that will probably get enough +1s anyway.
> 
> So, let's just vote and be done with it.

Besides the fact that the code was already reverted, we've gone through
the trouble of coming up with (and even documenting) the policy/procedures
used in developing SpamAssassin, and in this case R-T-C mode.  If we
arbitrarily decide to ignore them, there was really no point in coming
up with them in the first place.

There needs to be a bugzilla ticket, with the patch attached, etc.

-- 
Randomly Generated Tagline:
"Ready?
  Why do your people always ask if someone is ready right before you're
  going to do something massively unwise?
  Tradition."    - Sinclair and Delenn, Babylon 5, "War Without End I"

Re: svn commit: rev 22962 - in spamassassin/trunk/lib/Mail: . SpamAssassin SpamAssassin/Message

Posted by Michael Parker <pa...@pobox.com>.
On Fri, Jul 16, 2004 at 12:10:05PM -0700, Daniel Quinlan wrote:
> Theo Van Dinter <fe...@kluge.net> writes:
> 
> > Note: I'm not against the idea of making the change, I'm against this
> > being considered "trivial" and committed without comment by the rest of
> > the dev team.
> 
> Well, reason enough.

+1 for the change, I agree that it needs a vote, but I don't agree
that we need to spend a lot of time debating that it needs a vote and
reverting the code that will probably get enough +1s anyway.

So, let's just vote and be done with it.

Michael


Re: svn commit: rev 22962 - in spamassassin/trunk/lib/Mail: . SpamAssassin SpamAssassin/Message

Posted by Daniel Quinlan <qu...@pathname.com>.
Theo Van Dinter <fe...@kluge.net> writes:

> Note: I'm not against the idea of making the change, I'm against this
> being considered "trivial" and committed without comment by the rest of
> the dev team.

Well, reason enough.

-- 
Daniel Quinlan
http://www.pathname.com/~quinlan/

Re: svn commit: rev 22962 - in spamassassin/trunk/lib/Mail: . SpamAssassin SpamAssassin/Message

Posted by Theo Van Dinter <fe...@kluge.net>.
On Fri, Jul 16, 2004 at 11:28:02AM -0700, Dan Quinlan wrote:
> Sorry, it seemed trivial and non-controversial because it's a new API in
> 3.0, avoids confusion, lock-in after 3.0 final, and, well, misspelling a
> function name would be embarrassing.

All good reasons, but it's still an API change and needs to be voted
on before inclusion.  IMO, API changes at this stage of 3.0.0 are
non-trivial.

Note: I'm not against the idea of making the change, I'm against this
being considered "trivial" and committed without comment by the rest of
the dev team.

-- 
Randomly Generated Tagline:
"No one cares if you backup - only if you can restore."
         - W. Curtis Preston, Unix Backup & Recovery from O'Reilly

Re: svn commit: rev 22962 - in spamassassin/trunk/lib/Mail: . SpamAssassin SpamAssassin/Message

Posted by Daniel Quinlan <qu...@pathname.com>.
Theo Van Dinter <fe...@kluge.net> writes:

> Ummm.  Why exactly was this set of changes committed?  It may seem
> trivial, but it's an API change since you're renaming functions.

Sorry, it seemed trivial and non-controversial because it's a new API in
3.0, avoids confusion, lock-in after 3.0 final, and, well, misspelling a
function name would be embarrassing.

Daniel

-- 
Daniel Quinlan
http://www.pathname.com/~quinlan/

Re: svn commit: rev 22962 - in spamassassin/trunk/lib/Mail: . SpamAssassin SpamAssassin/Message

Posted by Theo Van Dinter <fe...@kluge.net>.
On Fri, Jul 16, 2004 at 08:33:20AM -0000, quinlan@apache.org wrote:
> Author: quinlan
> Date: Fri Jul 16 01:33:20 2004
> New Revision: 22962
> 
> -sub get_mbox_seperator {
> +sub get_mbox_separator {
>    return $_[0]->{mbox_sep};
>  }

Ummm.  Why exactly was this set of changes committed?  It may seem
trivial, but it's an API change since you're renaming functions.

-- 
Randomly Generated Tagline:
Error Loading Reality.Sys ... Universe Halted!